@@ -10,6 +10,8 @@ register(User)
 register(Group)
 
 class FollowTest(TestCase):
+    urls = 'follow.urls'
+
     def setUp(self):
         
         self.lennon = User.objects.create(username='lennon')
@@ -47,6 +49,14 @@ class FollowTest(TestCase):
         
         result = self.lennon.get_follows()
         self.assertEqual(0, len(result), result)
+        
+        utils.toggle(self.lennon, self.hendrix)
+        self.assertEqual(0, len(self.hendrix.get_follows()))
+        
+        utils.toggle(self.lennon, self.hendrix)
+        self.assertEqual(1, len(self.hendrix.get_follows()))
+        
+        
     
     def test_follow_http(self):
         self.client.login(username='lennon', password='test')
